@@ -2,10 +2,10 @@ import os
 
 import googlemaps
 
-from utils import timex
 from utils.cache import cache
+from utils.time.TimeUnit import SECONDS_IN
 
-CACHE_NAME, CACHE_TIMEOUT = 'GoogleMaps', timex.SECONDS_IN.YEAR
+CACHE_NAME, CACHE_TIMEOUT = 'GoogleMaps', SECONDS_IN.AVG_YEAR
 
 
 def get_api_key():
